DATA_DIR = "/usr/local/share"
LIB_DIR = "/usr/local/lib"
VERSION = "2.28.2"
PACKAGE = "hamster-applet"
PYTHONDIR = "/usr/local/lib/python2.5/site-packages"
